# -*- coding: utf-8 -*-

# chirptext's package version information
__author__ = "Le Tuan Anh"
__email__ = "tuananh.ke@gmail.com"
__copyright__ = "Copyright (c) 2012, Le Tuan Anh"
__credits__ = []
__license__ = "MIT License"
__description__ = "A minimalist collection of text processing tools for Python 3"
__url__ = "https://github.com/letuananh/chirptext/"
__maintainer__ = "Le Tuan Anh"
__version_major__ = "0.1"
__version__ = "{}rc2".format(__version_major__)
__version_long__ = "{} - release candidate 2".format(__version_major__)
__status__ = "Release candidate"
